@@ -1,5 +1,5 @@
 package WWW::Eksi;
-$WWW::Eksi::VERSION = '0.30';
+$WWW::Eksi::VERSION = '0.31';
 =head1 NAME
 
 WWW::Eksi - Interface for Eksisozluk.com
@@ -19,7 +19,8 @@ Provides easy access to entries and lists of entries.
   my @ghebe_slow = $e->ghebe(5); # add a politeness delay
 
   # Yesterday's most popular entries
-  my @doludolu   = $e->doludolu(5);
+  my @debe_fast = $e->debe;    # might get rate limited
+  my @debe_slow = $e->debe(5); # add a politeness delay
 
   # Single entry
   my $entry   = $e->download_entry(1);
@@ -48,17 +49,17 @@ Returns a new WWW::Eksi object.
 
 =cut
 
-sub new{
+sub new {
   my $class = shift;
   my $today = DateTime->now->ymd;
 
   my $eksi = {
     base     => 'https://eksisozluk.com',
     entry    => 'https://eksisozluk.com/entry/',
+    debe     => 'https://eksisozluk.com/istatistik/dunun-en-begenilen-entryleri',
     ghebe    => 'https://eksisozluk.com/istatistik/gecen-haftanin-en-begenilen-entryleri',
     strp_dt  => DateTime::Format::Strptime->new( pattern => '%d.%m.%Y%H:%M'),
     strp_d   => DateTime::Format::Strptime->new( pattern => '%d.%m.%Y'),
-    doludolu => 'https://eksisozluk.com/basliklar/ara?SearchForm.When.From='.$today.'T00:00:00&SearchForm.When.To='.$today.'T23:59:59&SearchForm.SortOrder=Count',
   };
 
   return bless $eksi, $class;
@@ -88,14 +89,14 @@ Takes entry id as argument, returns its data (if available) as follows.
 
 =cut
 
-sub download_entry{
+sub download_entry {
   my ($self,$id) = @_;
   my $data = $self->_download($self->{entry}.$id) if ($id && $id=~/^\d{1,}$/);
   return unless $data;
   return $self->_parse_entry($data,$id);
 }
 
-sub _parse_entry{
+sub _parse_entry {
   my ($self,$data, $id) = @_;
   return unless $data;
 
@@ -189,59 +190,44 @@ Ordered from more popular to less popular.
 
 =cut
 
-sub ghebe{
-  my $self      = shift;
-  my $sleep_sec = shift // 0;
-  my $data      = $self->_download($self->{ghebe});
+sub ghebe {
+  my ($self, $sleep_seconds) = @_;
+  return $self->_get_list($sleep_seconds,$self->{ghebe});
+}
+
+=head2 debe($politeness_delay)
+
+Returns an array of entries for top posts of yesterday.
+Ordered from more popular to less popular.
+
+=cut
+
+sub debe {
+  my ($self, $sleep_seconds) = @_;
+  return $self->_get_list($sleep_seconds,$self->{debe});
+}
+
+sub _get_list {
+  my ($self, $sleep_seconds, $url) = @_;
+  $sleep_seconds //= 0;
+  my $data = $self->_download($url);
   return unless $data;
 
   my $dom   = Mojo::DOM->new($data);
   my $links = $dom->at('ol[class~=stats]')->find('a');
   my $ids   = $links->map(sub{$_->{href}=~m/%23(\d+)$/})->to_array;
-  my @ghebe = ();
+  my @entries = ();
 
   foreach my $id (@$ids){
     my $entry = $self->download_entry($id);
-    push @ghebe, $entry;
-    sleep $sleep_sec;
+    push @entries, $entry;
+    sleep $sleep_seconds
   }
 
-  return @ghebe;
+  return @entries;
 }
 
-=head2 doludolu($politeness_delay)
-
-Returns an array of entries for top posts of yesterday.
-Ordered from more popular to less popular.
-This is an alternative list to DEBE, which is discontinued.
-
-=cut
-
-sub doludolu{
-  my $self      = shift;
-  my $sleep_sec = shift // 0;
-  my $data      = $self->_download($self->{doludolu});
-  my @doludolu  = ();
-  return unless $data;
-
-  my $dom   = Mojo::DOM->new($data);
-  my $links = $dom
-            ->at('ul[class=topic-list]')
-            ->find('a')
-            ->map(sub{$_->{href}=~m/^(.*)\?/})
-            ->to_array;
-
-  foreach my $link (@$links){
-    my $entry_html = $self->_download($self->{base}.$link.'?a=dailynice');
-    my $entry_hash = $self->_parse_entry($entry_html);
-    push @doludolu, $entry_hash;
-    sleep $sleep_sec;
-  }
-
-  return @doludolu;
-}
-
-sub _download{
+sub _download {
   my ($self,$url) = @_;
 
   my $u = URI->new($url) if $url;
@@ -254,7 +240,7 @@ sub _download{
     : 0;
 }
 
-sub _lengthen{
+sub _lengthen {
   my ($self, $url) = @_;
 
   my $u = URI->new($url) if $url;
@@ -267,7 +253,7 @@ sub _lengthen{
          : $u;
 }
 
-sub _process_entry{
+sub _process_entry {
   my ($self,$e) = @_;
   return unless $e;
 
@@ -296,7 +282,7 @@ sub _process_entry{
 
 }
 
-sub _entry_not_found{
+sub _entry_not_found {
 
   return {
     topic_title    => '?',
